---
name: Bug Report
about: Write a report to help us improve

---

**Describe the bug**

A clear and concise description of what the bug is.

**Failing Test**

Please put the code (ideally in the form of a unit
test) which fails below

**Expected behavior**

A clear and concise description of what you expected to happen.

**Screenshots**

If applicable, add screenshots to help explain your problem.

**System (please complete the following information):**

 - OS: [e.g. Windows, Linux, macOS]
 - Python version [e.g. Python 3.6] and output of `conda list --export` and `pip freeze` as applicable

**Additional context**

Add any other context about the problem here.
